<?php

/**
 * @file
 * Hooks related to Status Dashboard Client.
 */

/**
 * @addtogroup hooks
 * @{
 */

/**
 * Alter the JSON response sent to the status dashboard.
 *
 * This hook allows other modules to modify or add data to the JSON response
 * generated by the Status Dashboard Client module before it is sent to the
 * external status dashboard service. This is useful for appending additional
 * information such as project-specific data, for example -
 * current PHP version and the last time cron was run.
 * By leveraging this hook, modules can customize the status report to include
 * any necessary details relevant to the project.
 *
 * @param array &$json_response
 *   The JSON response array to be sent to the status dashboard.
 * @param array $projects_data
 *   Metadata and environment details related to the project.
 *
 * @see \Drupal\status_dashboard_client\Controller\StatusDashboardController::doCheck()
 */
function hook_status_dashboard_json_response_alter(array &$json_response, array $projects_data) {
  // Example: Add PHP version to the JSON response.
  $json_response['php_version'] = phpversion();

  // Example: Add the last time cron was run.
  $json_response['cron_last_run'] = \Drupal::state()->get('system.cron_last');
}

/**
 * @} End of "addtogroup hooks".
 */
